package meerkat.bulletinboard;


import com.google.protobuf.ByteString;
import meerkat.protobuf.Crypto.*;
import meerkat.protobuf.BulletinBoardAPI.*;
import meerkat.rest.Constants;
import meerkat.rest.ProtobufMessageBodyReader;
import meerkat.rest.ProtobufMessageBodyWriter;

import org.junit.Before;
import org.junit.Test;

import javax.ws.rs.client.Client;
import javax.ws.rs.client.ClientBuilder;
import javax.ws.rs.client.Entity;
import javax.ws.rs.client.WebTarget;
import javax.ws.rs.core.Response;

public class SQLiteServerIntegrationTest {

    private static String PROP_GETTY_URL = "gretty.httpBaseURI";
    private static String DEFAULT_BASE_URL = "localhost:8082";
    private static String BASE_URL =  System.getProperty(PROP_GETTY_URL, DEFAULT_BASE_URL);
    private static String SQL_SERVER_URL = "sqlserver/postmessage";

    Client client;

    @Before
    public void setup() throws Exception {
        client = ClientBuilder.newClient();
        client.register(ProtobufMessageBodyReader.class);
        client.register(ProtobufMessageBodyWriter.class);
    }

    @Test
    public void testPost() throws Exception {
        byte[] b1 = {(byte) 1, (byte) 2, (byte) 3, (byte) 4};
        byte[] b2 = {(byte) 11, (byte) 12, (byte) 13, (byte) 14};
        byte[] b3 = {(byte) 21, (byte) 22, (byte) 23, (byte) 24};

        Response response;

        BulletinBoardMessage msg;

        msg = BulletinBoardMessage.newBuilder()
                .setMsg(UnsignedBulletinBoardMessage.newBuilder()
                        .addTags("Signature")
                        .addTags("Trustee")
                        .setData(ByteString.copyFrom(b1))
                        .build())
                .setSig(Signature.newBuilder()
                        .setType(SignatureType.DSA)
                        .setData(ByteString.copyFrom(b2))
                        .setSignerId(ByteString.copyFrom(b3))
                        .build())
                .build();

        System.err.println("******** Testing: " + SQL_SERVER_URL);
        WebTarget webTarget = client.target(BASE_URL).path(SQL_SERVER_URL);
        response = webTarget.request(Constants.MEDIATYPE_PROTOBUF).post(Entity.entity(msg, Constants.MEDIATYPE_PROTOBUF));
        System.err.println(response);
        BoolMsg bool = response.readEntity(BoolMsg.class);
    	assert bool.getValue();
        
    }

}
